Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(179)

Unified Diff: chrome/browser/ui/views/session_crashed_bubble_view.cc

Issue 2215993002: Allow changing metrics reporting state without callback. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: fix func name Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/session_crashed_bubble_view.cc
diff --git a/chrome/browser/ui/views/session_crashed_bubble_view.cc b/chrome/browser/ui/views/session_crashed_bubble_view.cc
index d51bdf9feddeca8f0e704d381e824ad37b950e2d..f45bebb9a12ea36ca4967dfd6af2c2ce2854e8a1 100644
--- a/chrome/browser/ui/views/session_crashed_bubble_view.cc
+++ b/chrome/browser/ui/views/session_crashed_bubble_view.cc
@@ -91,9 +91,9 @@ void RecordBubbleHistogramValue(SessionCrashedBubbleHistogramValue value) {
// Whether or not the bubble UI should be used.
bool IsBubbleUIEnabled() {
// Function InitiateMetricsReportingChange (called when the user chooses to
// opt-in to UMA) does not support Chrome OS yet, so don't show the bubble on
// Chrome OS.
#if defined(OS_CHROMEOS)
return false;
#else
@@ -410,7 +410,7 @@ void SessionCrashedBubbleView::RestorePreviousSession() {
// Record user's choice for opt-in in to UMA.
// There's no opt-out choice in the crash restore bubble.
if (uma_option_ && uma_option_->checked()) {
- InitiateMetricsReportingChange(true, OnMetricsReportingCallbackType());
+ ChangeMetricsReportingState(true);
RecordBubbleHistogramValue(SESSION_CRASHED_BUBBLE_UMA_OPTIN);
}
CloseBubble();
@@ -91,9 +91,9 @@ void RecordBubbleHistogramValue(SessionCrashedBubbleHistogramValue value) {
// Whether or not the bubble UI should be used.
bool IsBubbleUIEnabled() {
- // Function InitiateMetricsReportingChange (called when the user chooses to
- // opt-in to UMA) does not support Chrome OS yet, so don't show the bubble on
- // Chrome OS.
+// Function ChangeMetricsReportingState (called when the user chooses to
+// opt-in to UMA) does not support Chrome OS yet, so don't show the bubble on
+// Chrome OS.
#if defined(OS_CHROMEOS)
return false;
« no previous file with comments | « chrome/browser/ui/views/first_run_dialog.cc ('k') | chrome/browser/ui/webui/options/browser_options_handler.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698